@@ -247,7 +247,7 @@ public:
         Returns a list of consecutive dates, starting with @p start and ending
         with @p end. If either start or end are invalid, a list with
         QDate::currentDate() is returned */
-    static QList<QDate> generateDateList(const QDate &start, const QDate &end);
+    static QList<QDate> generateDateList(QDate start, QDate end);
 
     void changeColumns(int numColumns);
 
@@ -360,7 +360,7 @@ void AgendaView::Private::changeColumns(int numColumns)
 }
 
 /** static */
-QList<QDate> AgendaView::Private::generateDateList(const QDate &start, const QDate &end)
+QList<QDate> AgendaView::Private::generateDateList(QDate start, QDate end)
 {
     QList<QDate> list;
 
@@ -440,7 +440,7 @@ void AgendaView::Private::calendarIncidenceChanged(const KCalendarCore::Incidenc
         KCalendarCore::Incidence::Ptr originalIncidence = agendaItems.first()->incidence();
 
         if (datesEqual(originalIncidence, incidence)) {
-            for (const AgendaItem::QPtr &agendaItem : qAsConst(agendaItems)) {
+            for (const AgendaItem::QPtr &agendaItem : std::as_const(agendaItems)) {
                 agendaItem->setIncidence(KCalendarCore::Incidence::Ptr(incidence->clone()));
                 agendaItem->update();
             }
@@ -699,7 +699,7 @@ AgendaView::AgendaView(QDate start, QDate end, bool isInteractive, bool isSideBy
     init(start, end);
 }
 
-AgendaView::AgendaView(const PrefsPtr &prefs, const QDate &start, const QDate &end, bool isInteractive, bool isSideBySide, QWidget *parent)
+AgendaView::AgendaView(const PrefsPtr &prefs, QDate start, QDate end, bool isInteractive, bool isSideBySide, QWidget *parent)
     : EventView(parent)
     , d(new Private(this, isInteractive, isSideBySide))
 {
@@ -824,7 +824,7 @@ void AgendaView::init(QDate start, QDate end)
 
 AgendaView::~AgendaView()
 {
-    for (const ViewCalendar::Ptr &cal : qAsConst(d->mViewCalendar->mSubCalendars)) {
+    for (const ViewCalendar::Ptr &cal : std::as_const(d->mViewCalendar->mSubCalendars)) {
         if (cal->getCalendar()) {
             cal->getCalendar()->unregisterObserver(d);
         }
@@ -899,7 +899,7 @@ void AgendaView::connectAgenda(Agenda *agenda, Agenda *otherAgenda)
             QOverload<const QList<QUrl> &, const QPoint &, bool>::of(&AgendaView::slotIncidencesDropped));
 }
 
-void AgendaView::slotIncidenceSelected(const KCalendarCore::Incidence::Ptr &incidence, const QDate &date)
+void AgendaView::slotIncidenceSelected(const KCalendarCore::Incidence::Ptr &incidence, QDate date)
 {
     Akonadi::Item item = d->mViewCalendar->item(incidence);
     if (item.isValid()) {
@@ -907,7 +907,7 @@ void AgendaView::slotIncidenceSelected(const KCalendarCore::Incidence::Ptr &inci
     }
 }
 
-void AgendaView::slotShowIncidencePopup(const KCalendarCore::Incidence::Ptr &incidence, const QDate &date)
+void AgendaView::slotShowIncidencePopup(const KCalendarCore::Incidence::Ptr &incidence, QDate date)
 {
     Akonadi::Item item = d->mViewCalendar->item(incidence);
     // qDebug() << "wanna see the popup for " << incidence->uid() << item.id();
@@ -968,7 +968,7 @@ void AgendaView::zoomOutVertically()
     }
 }
 
-void AgendaView::zoomInHorizontally(const QDate &date)
+void AgendaView::zoomInHorizontally(QDate date)
 {
     QDate begin;
     QDate newBegin;
@@ -976,7 +976,7 @@ void AgendaView::zoomInHorizontally(const QDate &date)
     int ndays, count;
 
     begin = d->mSelectedDates.first();
-    ndays = begin.daysTo(d->mSelectedDates.last());
+    ndays = begin.daysTo(d->mSelectedDates.constLast());
 
     // zoom with Action and are there a selected Incidence?, Yes, I zoom in to it.
     if (!dateToZoom.isValid()) {
@@ -1001,7 +1001,7 @@ void AgendaView::zoomInHorizontally(const QDate &date)
     }
 }
 
-void AgendaView::zoomOutHorizontally(const QDate &date)
+void AgendaView::zoomOutHorizontally(QDate date)
 {
     QDate begin;
     QDate newBegin;
@@ -1009,7 +1009,7 @@ void AgendaView::zoomOutHorizontally(const QDate &date)
     int ndays, count;
 
     begin = d->mSelectedDates.first();
-    ndays = begin.daysTo(d->mSelectedDates.last());
+    ndays = begin.daysTo(d->mSelectedDates.constLast());
 
     // zoom with Action and are there a selected Incidence?, Yes, I zoom out to it.
     if (!dateToZoom.isValid()) {
@@ -1032,7 +1032,7 @@ void AgendaView::zoomOutHorizontally(const QDate &date)
     }
 }
 
-void AgendaView::zoomView(const int delta, const QPoint &pos, const Qt::Orientation orient)
+void AgendaView::zoomView(const int delta, QPoint pos, const Qt::Orientation orient)
 {
     // TODO find out why this is necessary. seems to be some kind of performance hack
     static QDate zoomDate;
@@ -1100,9 +1100,9 @@ void AgendaView::placeDecorationsFrame(QFrame *frame, bool decorationsFound, boo
     }
 }
 
-void AgendaView::placeDecorations(DecorationList &decoList, const QDate &date, QWidget *labelBox, bool forWeek)
+void AgendaView::placeDecorations(DecorationList &decoList, QDate date, QWidget *labelBox, bool forWeek)
 {
-    for (CalendarDecoration::Decoration *deco : qAsConst(decoList)) {
+    for (CalendarDecoration::Decoration *deco : std::as_const(decoList)) {
         const CalendarDecoration::Element::List elements = forWeek ? deco->weekElements(date) : deco->dayElements(date);
         if (!elements.isEmpty()) {
             auto decoHBox = new QFrame(labelBox);
@@ -1148,7 +1148,7 @@ void AgendaView::createDayLabels(bool force)
     d->mLayoutTopDayLabels->setSpacing(1);
 
     // this spacer moves the day labels over to line up with the day columns
-    auto *spacer =
+    auto spacer =
         new QSpacerItem((!d->mIsSideBySide ? d->mTimeLabelsZone->width() : 0) + SPACING + d->mAllDayAgenda->scrollArea()->frameWidth(), 1, QSizePolicy::Fixed);
 
     d->mLayoutTopDayLabels->addSpacerItem(spacer);
@@ -1182,7 +1182,7 @@ void AgendaView::createDayLabels(bool force)
     placeDecorationsFrame(d->mBottomDayLabelsFrame, loadDecorations(botStrDecos, botDecos), false);
 #endif
 
-    for (const QDate &date : qAsConst(d->mSelectedDates)) {
+    for (const QDate &date : std::as_const(d->mSelectedDates)) {
         auto topDayLabelBox = new QFrame(d->mTopDayLabels);
         auto topDayLabelBoxLayout = new QVBoxLayout(topDayLabelBox);
         topDayLabelBoxLayout->setContentsMargins(0, 0, 0, 0);
@@ -1215,10 +1215,10 @@ void AgendaView::createDayLabels(bool force)
         d->mDateDayLabels.append(dayLabel);
         // if a holiday region is selected, show the holiday name
         const QStringList texts = CalendarSupport::holiday(date);
+        const int columnWidth = (d->mTopDayLabelsFrame->width() - (!d->mIsSideBySide ? d->mTimeLabelsZone->width() : 0)
+            - SPACING - d->mAllDayAgenda->scrollArea()->frameWidth()) / d->mSelectedDates.count();
         for (const QString &text : texts) {
-            // Compute a small version of the holiday string for AlternateLabel
-            const KWordWrap ww = KWordWrap::formatText(fm, topDayLabelBox->rect(), 0, text, -1);
-            auto label = new AlternateLabel(ww.truncatedString(), text, text, topDayLabelBox);
+            auto label = new AlternateLabel(fm.elidedText(text, Qt::ElideRight, columnWidth), text, text, topDayLabelBox);
             topDayLabelBoxLayout->addWidget(label);
             label->setAlignment(Qt::AlignCenter);
         }
@@ -1257,7 +1257,7 @@ void AgendaView::updateDayLabelSizes()
 {
     // First, calculate the maximum text type that fits for all labels
     AlternateLabel::TextType overallType = AlternateLabel::Extensive;
-    for (AlternateLabel *label : qAsConst(d->mDateDayLabels)) {
+    for (AlternateLabel *label : std::as_const(d->mDateDayLabels)) {
         AlternateLabel::TextType type = label->largestFittingTextType();
         if (type < overallType) {
             overallType = type;
@@ -1265,7 +1265,7 @@ void AgendaView::updateDayLabelSizes()
     }
 
     // Then, set that maximum text type to all the labels
-    for (AlternateLabel *label : qAsConst(d->mDateDayLabels)) {
+    for (AlternateLabel *label : std::as_const(d->mDateDayLabels)) {
         label->setFixedType(overallType);
     }
 }
@@ -1423,7 +1423,7 @@ void AgendaView::updateTimeBarWidth()
     QFontMetrics fm(labelFont);
 
     int width = d->mTimeLabelsZone->preferedTimeLabelsWidth();
-    for (QLabel *l : qAsConst(d->mTimeBarHeaders)) {
+    for (QLabel *l : std::as_const(d->mTimeBarHeaders)) {
         const auto lst = l->text().split(QLatin1Char(' '));
         for (const QString &word : lst) {
             width = qMax(width, fm.boundingRect(word).width());
@@ -1939,7 +1939,7 @@ void AgendaView::slotIncidencesDropped(const QList<QUrl> &items, const QPoint &g
 #endif
 }
 
-static void setDateTime(KCalendarCore::Incidence::Ptr incidence, QDateTime dt, bool allDay)
+static void setDateTime(KCalendarCore::Incidence::Ptr incidence, const QDateTime &dt, bool allDay)
 {
     incidence->setAllDay(allDay);
 
@@ -1983,7 +1983,7 @@ void AgendaView::slotIncidencesDropped(const KCalendarCore::Incidence::List &inc
         const bool existsInSameCollection = existingItem.isValid() && (existingItem.storageCollectionId() == collectionId() || collectionId() == -1);
 
         if (existingItem.isValid() && existsInSameCollection) {
-            KCalendarCore::Incidence::Ptr newIncidence = existingItem.payload<KCalendarCore::Incidence::Ptr>();
+            auto newIncidence = existingItem.payload<KCalendarCore::Incidence::Ptr>();
 
             if (newIncidence->dtStart() == newTime && newIncidence->allDay() == allDay) {
                 // Nothing changed
