@@ -113,7 +113,7 @@ MonthCell *MonthScene::firstCellForMonthItem(MonthItem *manager)
 
 void MonthScene::updateGeometry()
 {
-    for (MonthItem *manager : qAsConst(mManagerList)) {
+    for (MonthItem *manager : std::as_const(mManagerList)) {
         manager->updateGeometry();
     }
 }
@@ -443,7 +443,7 @@ void MonthScene::scrollCellsDown()
     int newHeight = startHeight() + 1;
     setStartHeight(newHeight);
 
-    for (MonthItem *manager : qAsConst(mManagerList)) {
+    for (MonthItem *manager : std::as_const(mManagerList)) {
         manager->updateGeometry();
     }
 
@@ -455,7 +455,7 @@ void MonthScene::scrollCellsUp()
     int newHeight = startHeight() - 1;
     setStartHeight(newHeight);
 
-    for (MonthItem *manager : qAsConst(mManagerList)) {
+    for (MonthItem *manager : std::as_const(mManagerList)) {
         manager->updateGeometry();
     }
 
@@ -677,7 +677,7 @@ bool MonthScene::isInMonthGrid(int x, int y) const
 
 // The function converts the coordinates to the month grid coordinates to
 // be able to locate the cell.
-MonthCell *MonthScene::getCellFromPos(const QPointF &pos)
+MonthCell *MonthScene::getCellFromPos(QPointF pos)
 {
     int y = sceneYToMonthGridY(static_cast<int>(pos.y()));
     int x = sceneXToMonthGridX(static_cast<int>(pos.x()));
@@ -722,7 +722,7 @@ void MonthScene::selectItem(MonthItem *item)
 
 void MonthScene::removeIncidence(const QString &uid)
 {
-    for (MonthItem *manager : qAsConst(mManagerList)) {
+    for (MonthItem *manager : std::as_const(mManagerList)) {
         auto imi = qobject_cast<IncidenceMonthItem *>(manager);
         if (!imi) {
             continue;
