@@ -1,35 +1,19 @@
 /*
-  Copyright (c) 2008 Bruno Virlet <bruno.virlet@gmail.com>
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Bertjan Broeksema, broeksema@kde.org
+  SPDX-FileCopyrightText: 2008 Bruno Virlet <bruno.virlet@gmail.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Bertjan Broeksema <broeksema@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef EVENTVIEWS_MONTHVIEW_H
-#define EVENTVIEWS_MONTHVIEW_H
+#pragma once
 
 #include "eventview.h"
 
 class QModelIndex;
 
-namespace EventViews {
+namespace EventViews
+{
 class MonthViewPrivate;
 
 /**
@@ -39,10 +23,7 @@ class EVENTVIEWS_EXPORT MonthView : public EventView
 {
     Q_OBJECT
 public:
-    enum NavButtonsVisibility {
-        Visible,
-        Hidden
-    };
+    enum NavButtonsVisibility { Visible, Hidden };
 
     explicit MonthView(NavButtonsVisibility visibility = Visible, QWidget *parent = nullptr);
     ~MonthView() override;
@@ -53,7 +34,7 @@ public:
     Q_REQUIRED_RESULT Akonadi::Item::List selectedIncidences() const override;
 
     /** Returns dates of the currently selected events */
-    Q_REQUIRED_RESULT KCalCore::DateList selectedIncidenceDates() const override;
+    Q_REQUIRED_RESULT KCalendarCore::DateList selectedIncidenceDates() const override;
 
     Q_REQUIRED_RESULT QDateTime selectionStart() const override;
 
@@ -75,7 +56,7 @@ public:
         return false;
     }
 
-    Q_REQUIRED_RESULT bool isBusyDay(const QDate &day) const;
+    Q_REQUIRED_RESULT bool isBusyDay(QDate day) const;
 
     void setCalendar(const Akonadi::ETMCalendar::Ptr &cal) override;
 
@@ -91,10 +72,10 @@ public Q_SLOTS:
 
     void changeIncidenceDisplay(const Akonadi::Item &, int);
     void changeFullView(); /// Display in full window mode
-    void moveBackMonth();  /// Shift the view one month back
-    void moveBackWeek();   /// Shift the view one week back
-    void moveFwdWeek();    /// Shift the view one week forward
-    void moveFwdMonth();   /// Shift the view one month forward
+    void moveBackMonth(); /// Shift the view one month back
+    void moveBackWeek(); /// Shift the view one week back
+    void moveFwdWeek(); /// Shift the view one week forward
+    void moveFwdMonth(); /// Shift the view one month forward
 
 protected Q_SLOTS:
     void calendarReset() override;
@@ -111,8 +92,7 @@ protected:
     void keyPressEvent(QKeyEvent *event) override;
     void keyReleaseEvent(QKeyEvent *event) override;
 
-    QPair<QDateTime, QDateTime> actualDateRange(
-        const QDateTime &start, const QDateTime &end, const QDate &preferredMonth = QDate()) const override;
+    QPair<QDateTime, QDateTime> actualDateRange(const QDateTime &start, const QDateTime &end, const QDate &preferredMonth = QDate()) const override;
 
     // Compute and update the whole view
     void reloadIncidences();
@@ -130,4 +110,3 @@ private:
 };
 }
 
-#endif
